@@ -1,12 +1,10 @@
 use strict;
 use warnings;
-package Test::LWP::UserAgent;
-# git description: v0.025-10-geef9264
-$Test::LWP::UserAgent::VERSION = '0.026';
+package Test::LWP::UserAgent; # git description: v0.026-11-g6c86d85
 # ABSTRACT: A LWP::UserAgent suitable for simulating and testing network calls
 # KEYWORDS: testing useragent networking mock server client
 # vim: set ts=8 sw=4 tw=78 et :
-
+our $VERSION = '0.027';
 use parent 'LWP::UserAgent';
 use Scalar::Util qw(blessed reftype);
 use Storable 'freeze';
@@ -85,6 +83,7 @@ sub map_response
     {
         push @response_map, [ $request_description, $response ];
     }
+    return $self;
 }
 
 sub map_network_response
@@ -102,6 +101,7 @@ sub map_network_response
         push @response_map,
             [ $request_description, sub { LWP::UserAgent->new->send_request($_[0]) } ];
     }
+    return $self;
 }
 
 sub unmap_all
@@ -119,6 +119,7 @@ sub unmap_all
             if $instance_only;
         @response_map = ();
     }
+    return $self;
 }
 
 sub register_psgi
@@ -154,6 +155,7 @@ sub unregister_psgi
     {
         @response_map = grep { $_->[0] ne $domain } @response_map;
     }
+    return $self;
 }
 
 sub last_http_request_sent
@@ -339,7 +341,7 @@ Test::LWP::UserAgent - A LWP::UserAgent suitable for simulating and testing netw
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
@@ -529,6 +531,8 @@ Instance mappings take priority over global (class method) mappings - if no
 matches are found from mappings added to the instance, the global mappings are
 then examined. When no matches have been found, a 404 response is returned.
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<map_network_response($request_description)>
 
 Same as C<map_response> above, only requests that match this description will
@@ -540,6 +544,8 @@ are used for making the real network call. If called as a class method, a
 pristine L<LWP::UserAgent> object with no customized options will be used
 instead.
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<unmap_all(instance_only?)>
 
 When called as a class method, removes all mappings set up globally (across all
@@ -550,6 +556,8 @@ this instance, unless a true value is passed as an argument, in which only
 mappings local to the object will be removed. (Any true value will do, so you
 can pass a meaningful string.)
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<register_psgi($domain, $app)>
 
 Register a particular L<PSGI> app (code reference) to be used when requests
@@ -574,6 +582,8 @@ a server so as to test your client code.
 You might find using L<Plack::Test> or L<Plack::Test::ExternalServer> easier
 for your needs, so check those out as well.
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<unregister_psgi($domain, instance_only?)>
 
 When called as a class method, removes a domain->PSGI app entry that had been
@@ -590,6 +600,8 @@ then add C<undef> as a mapping on your instance:
 
     $useragent->map_response($domain, undef);
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<last_http_request_sent>
 
 The last L<HTTP::Request> object that this object (if called on an object) or
@@ -749,4 +761,10 @@ This software is copyright (c) 2012 by Karen Etheridge.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Tom Hukins
+
+Tom Hukins <tom@eborcom.com>
+
 =cut
